Learn R Programming

loo (version 0.1.0)

gpdfit: Generalized Pareto distribution

Description

Estimate the parameters $k$ and $\sigma$ of the generalized Pareto distribution, given a sample $x$.

Usage

gpdfit(x)

Arguments

x
a numeric vector. The sample from which to estimate the parameters.

Value

  • a list. Estimates for $k$ and $\sigma$.

Details

Here the parameter $k$ is the negative of $k$ in Zhang & Stephens (2009).

References

Zhang, J., and Stephens, M. A. (2009). A new and efficient estimation method for the generalized Pareto distribution. Technometrics 51, 316-325.

See Also

vgislw, loo_and_waic, loo-package