Description
vgislw performs very good importance sampling. vgisloo calls
vgislw and does useful post-processing for computing LOO and WAIC.Usage
vgisloo(log_lik, ...)
Arguments
log_lik
an $S$ by $N$ matrix, where $S$ is the size of the
posterior sample and $N$ is the number of data points (see
extract_log_lik). ...
optional arguments to pass to vgislw. Value
vgislw returns a list with modified log weights and tail
indices. vgisloo calls vgislw(lw = -log_lik,...),
post-processes the results, and returns a named list with components
[object Object],[object Object],[object Object]